@@ -1,13 +1,14 @@
 package App::wordlist;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-18'; # DATE
+our $DATE = '2020-05-21'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.270'; # VERSION
+our $VERSION = '0.271'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
+use Log::ger;
 
 use List::Util qw(shuffle);
 
@@ -16,7 +17,10 @@ our %SPEC;
 our %arg_wordlists = (
     wordlists => {
         'x.name.is_plural' => 1,
-        schema => ['array*' => of => 'str*'],
+        schema => ['array*' => {
+            of => 'str*', # for the moment we need to use 'str' instead of 'perl::modname' due to Perinci::Sub::GetArgs::Argv limitation
+            'x.perl.coerce_rules'=>[ ['From_str_or_array::expand_perl_modname_wildcard'=>{ns_prefix=>"WordList"}] ],
+        }],
         summary => 'Select one or more wordlist modules',
         cmdline_aliases => {w=>{}},
         element_completion => sub {
@@ -207,12 +211,13 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
-        #{
-        #    argv => [qw/-t Phrase foo/],
-        #    summary => 'Select phrase wordlists (multiple -t allowed)',
-        #    test => 0,
-        #    'x.doc.show_result' => 0,
-        #},
+        {
+            argv => [qw/-w ID::** foo/],
+            summary => 'Select all ID::* wordlists (wildcard will be expanded)',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+
         {
             argv => [qw/--lang FR foo/],
             summary => 'Select French wordlists (multiple --lang allowed)',
@@ -283,6 +288,7 @@ sub wordlist {
             }
         }
         $wordlists = [shuffle @$wordlists] if $random;
+        log_trace "Wordlists to use: %s", $wordlists;
 
         my $n = 0;
 
@@ -312,6 +318,7 @@ sub wordlist {
             unless ($wl_obj) {
                 my $mod = "WordList::$wl";
                 (my $modpm = "$mod.pm") =~ s!::!/!g;
+                log_trace "Loading wordlist module $mod ...";
                 eval { require $modpm; $wl_obj = $mod->new };
                 if ($@) {
                     warn;
@@ -457,7 +464,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.270 of App::wordlist (from Perl distribution App-wordlist), released on 2020-05-18.
+This document describes version 0.271 of App::wordlist (from Perl distribution App-wordlist), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -498,6 +505,10 @@ Examples:
 
  wordlist( arg => ["foo"], wordlists => ["ID::KBBI"]);
 
+=item * Select all ID::* wordlists (wildcard will be expanded):
+
+ wordlist( arg => ["foo"], wordlists => ["ID::**"]);
+
 =item * Select French wordlists (multiple --lang allowed):
 
  wordlist( arg => ["foo"], langs => ["FR"]);
